@@ -1,10 +1,10 @@
 import logging
 import os
+from http import HTTPStatus
 
 from yajwt.jwt_keys_manager import JwtKeysManager
 from yajwt.jwt_requests_wrapper import JwtRequestsWrapper
 from yajwt.jwt_response_mapper import JwtResponseMapper
-from yajwt.entities.jwt_response_status import JwtResponseStatus
 
 TOKEN_TTL = 60 * 10  # we recommend 10 min
 
@@ -18,5 +18,5 @@ if __name__ == "__main__":
 
     # make the request
     response = jwt_requests.get("https://example.com", "testing-user")
-    if response.status == JwtResponseStatus.OK:
+    if response.status == HTTPStatus.OK:
         print(response)
